@@ -16,5 +16,7 @@ CREATE TABLE /*_*/mathoid (
   -- MW_MATHSTYLE_(INLINE_DISPLAYSTYLE|DISPLAY|INLINE)
   math_style SMALLINT,
     -- type of the Math input (TeX, MathML, AsciiMath...)
-  math_input_type SMALLINT
+  math_input_type SMALLINT,
+  -- png output of mathoid
+  math_png BYTEA
 ) /*$wgDBTableOptions*/;
