@@ -1,6 +1,7 @@
 ( function ( mw ) {
+	var iconPath;
 	if ( mw.toolbar ) {
-		var iconPath = mw.config.get( 'wgExtensionAssetsPath' ) + '/Math/images/';
+		iconPath = mw.config.get( 'wgExtensionAssetsPath' ) + '/Math/images/';
 		mw.toolbar.addButton( {
 			imageFile: iconPath + 'button_math.png',
 			speedTip: mw.msg( 'math_tip' ),
